@@ -2,7 +2,7 @@ package Net::IPAM::IP;
 
 use strict;
 use warnings;
-our $VERSION = '1.11';
+our $VERSION = '1.12';
 
 use Socket qw/AF_INET AF_INET6/;
 
@@ -421,37 +421,17 @@ sub _inet_ntop_v6_pp {
   my $n = shift // return;
   return if length($n) != 16;
 
-  # expand binary to hex, lower case, rule (1)
-  # 2001:0db8:85a3:0000:0000:8a2e:0370:7334
-  my $ip = join( ':', unpack( 'H4' x 8, $n ) );
+  # expand binary to hex, lower case, rule (1), leading zeroes squashed
+  # add : at left and right for symmetric squashing algo, see below
+  # :2001:db8:85a3:0:0:8a2e:370:7334:
+  my $ip = sprintf( ':%x:%x:%x:%x:%x:%x:%x:%x:', unpack( 'n8', $n ) );
 
-  # squash leading zeroes, rule (2)
-  # 2001:db8:85a3:0:0:8a2e:370:7334
-  $ip =~ s/\b 0{1,3}//gx;
-
-  # find all consecutive groups containing zeros
-  my $rx     = qr/(?:^|:) [0:]+ /x;
-  my @groups = $ip =~ m/$rx/g;
-
-  # find longest group (count zeros with tr///), rule (3)
-  # count zeros with tr///
-  my $max_str   = '';
-  my $max_zeros = 0;
-
-  foreach my $match (@groups) {
-    my $zeroes = $match =~ tr/0/0/;
-    if ( $zeroes > $max_zeros ) {
-      $max_zeros = $zeroes;
-      $max_str   = $match;
-    }
-  }
-
-  # the substitution may only be applied once in the address, rule (3,4)
-  # "::" is not used to shorten just a single 0 field
-  if ( $max_zeros >= 2 ) {
-    $ip =~ s/$max_str/::/;
-  }
+  # rule (3,4) # squash the longest sequence of consecutive all-zero fields
+  # e.g. :0:0: (?!not followed) :0\1
+  $ip =~ s/(:0[:0]+:) (?! .+ :0\1)/::/x;
 
+  $ip =~ s/^:// unless $ip =~ /^::/;    # trim additional left
+  $ip =~ s/:$// unless $ip =~ /::$/;    # trim additional right
   return $ip;
 }
 
